@@ -9,10 +9,13 @@ class DimensionTestSuite(BaseTestSuite):
         super(DimensionTestSuite, self).__init__(sparkSession, databaseName, tableName)
 
     def queue_tests(self) -> None:
+        
         dimensionTestCase = DimensionTestCase(self.SparkUtility, self.FieldInfo, self.DatabaseName, self.TableName, self.TableCount, self.CustomEvents)
         commonTestCase = CommonTestCase(self.TableDataFrame, self.FieldInfo, self.CustomEvents)
-        self.TestSuite.addTest(dimensionTestCase)
-        self.TestSuite.addTest(commonTestCase)
+        
+        testClasses = [dimensionTestCase, commonTestCase]
+
+        self.build_suite(testClasses)
 
     def run_tests(self) -> None:
         self.TestRunner.run(self.TestSuite)
\ No newline at end of file
